summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/religion.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/religion.cc')
-rw-r--r--crawl-ref/source/religion.cc18
1 files changed, 17 insertions, 1 deletions
diff --git a/crawl-ref/source/religion.cc b/crawl-ref/source/religion.cc
index fc1cdbd94f..4ba71a3b08 100644
--- a/crawl-ref/source/religion.cc
+++ b/crawl-ref/source/religion.cc
@@ -475,7 +475,7 @@ static void _inc_penance(god_type god, int val)
// orcish bonuses don't apply under penance
if (god == GOD_BEOGH)
you.redraw_armour_class = true;
// neither does Zin's revitalisation chaining
else if (god == GOD_ZIN)
{
if (you.duration[DUR_REVITALISATION_CHAIN])
@@ -483,6 +483,14 @@ static void _inc_penance(god_type god, int val)
mpr("Your power of revitalisation disappears!");
you.duration[DUR_REVITALISATION_CHAIN] = 0;
}
+
+ if (you.duration[DUR_DIVINE_ROBUSTNESS])
+ {
+ mpr("Your divine robustness is withdrawn.");
+ you.duration[DUR_DIVINE_ROBUSTNESS] = 0;
+ you.duration[DUR_REVITALISATION_CHAIN] = 0;
+ calc_hp();
+ }
}
// neither does TSO's halo or divine shield
else if (god == GOD_SHINING_ONE)
@@ -4311,6 +4319,14 @@ void excommunication(god_type new_god)
you.duration[DUR_REVITALISATION_CHAIN] = 0;
}
+ if (you.duration[DUR_DIVINE_ROBUSTNESS])
+ {
+ mpr("Your divine robustness is withdrawn.");
+ you.attribute[ATTR_DIVINE_ROBUSTNESS] = 0;
+ you.duration[DUR_DIVINE_ROBUSTNESS] = 0;
+ calc_hp();
+ }
+
if (env.sanctuary_time)
remove_sanctuary();
@@ -475,7 +475,7 @@ static void _inc_penance(god_type god, int val)
if (god == GOD_BEOGH)
you.redraw_armour_class = true;
- // neither does Zin's revitalisation chaining
+ // neither does Zin's revitalisation chaining or divine robustness
else if (god == GOD_ZIN)
{